summaryrefslogtreecommitdiff
path: root/lib/dsl.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/dsl.rb')
-rw-r--r--lib/dsl.rb7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/dsl.rb b/lib/dsl.rb
index 6185c98..e3f6ee2 100644
--- a/lib/dsl.rb
+++ b/lib/dsl.rb
@@ -71,10 +71,11 @@ module RCM
end
def configure(reset: false, &block)
# Parse ARGV each time configure is called so that scripts which call
# configure multiple times (or test suites that reset state) always
# start with a fresh, consistent option set.
RCM::Options.parse!
+ RCM::Config.load!
RCM::DSL.new(reset) do |rcm|
rcm.info('Configuring...')
rcm.instance_eval(&block)
@@ -71,10 +71,11 @@ module RCM
end
def configure(reset: false, &block)
- # Parse ARGV each time configure is called so that scripts which call
- # configure multiple times (or test suites that reset state) always
- # start with a fresh, consistent option set.
+ # Parse ARGV and load config.toml each time configure is called so that
+ # scripts and test suites that call configure multiple times always
+ # start from a consistent, freshly-loaded state.
RCM::Options.parse!